@@ -1,23 +1,21 @@
 /*
- * ARP Scan is Copyright (C) 2005-2013 Roy Hills, NTA Monitor Ltd.
+ * ARP Scan is Copyright (C) 2005-2016 Roy Hills, NTA Monitor Ltd.
  *
  * This file is part of arp-scan.
- * 
+ *
  * arp-scan is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- * 
+ *
  * arp-scan is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with arp-scan.  If not, see <http://www.gnu.org/licenses/>.
  *
- * $Id: arp-scan.h 19575 2013-04-25 12:41:29Z rsh $
- *
  * arp-scan.h -- Header file for ARP scanner
  *
  * Author:	Roy Hills
@@ -124,7 +122,9 @@
 #endif
 #endif
 
-#include "hash.h"		/* Hash table functions */
+#ifdef HAVE_SEARCH_H
+#include <search.h>
+#endif
 
 /* Defines */
 
@@ -132,13 +132,13 @@
 #define MAX_FRAME 2048			/* Maximum allowed frame size */
 #define REALLOC_COUNT 1000		/* Entries to realloc at once */
 #define DEFAULT_BANDWIDTH 256000	/* Default bandwidth in bits/sec */
-#define PACKET_OVERHEAD 18		/* layer 2 overhead (6+6+2 + 4) */ 
+#define PACKET_OVERHEAD 18		/* layer 2 overhead (6+6+2 + 4) */
 #define MINIMUM_FRAME_SIZE 46           /* Minimum layer 2 date size */
 #define DEFAULT_BACKOFF_FACTOR 1.5      /* Default timeout backoff factor */
 #define DEFAULT_RETRY 2                 /* Default number of retries */
 #define DEFAULT_TIMEOUT 500             /* Default per-host timeout in ms */
 #define SNAPLEN 64			/* 14 (ether) + 28 (ARP) + extra */
-#define PROMISC 0			/* Enable promiscuous mode */
+#define PROMISC 1			/* Enable promiscuous mode */
 #define TO_MS 0				/* Timeout for pcap_open_live() */
 #define OPTIMISE 1			/* Optimise pcap filter */
 #define ARPHRD_ETHER 1			/* Ethernet ARP type */
@@ -163,6 +163,8 @@
 #define ARRAY_SIZE(a) (sizeof (a) / sizeof ((a)[0]))
 #define OPT_WRITEPKTTOFILE 256		/* --writepkttofile option */
 #define OPT_READPKTFROMFILE 257		/* --readpktfromfile option */
+#define OPT_RANDOMSEED 258		/* --randomseed option */
+#define HASH_TABLE_SIZE 50000		/* Max size of OUI/Vendor hash table */
 
 /* Structures */
 
@@ -222,7 +224,6 @@ void display_packet(host_entry *, arp_ether_ipv4 *, const unsigned char *,
                     size_t, int, int, ether_hdr *, const struct pcap_pkthdr *);
 void advance_cursor(void);
 void dump_list(void);
-void print_times(void);
 void clean_up(pcap_t *);
 void arp_scan_version(void);
 char *make_message(const char *, ...);
@@ -240,7 +241,7 @@ unsigned char *hex2data(const char *, size_t *);
 unsigned int hstr_i(const char *);
 char *hexstring(const unsigned char *, size_t);
 int get_ether_addr(const char *, unsigned char *);
-int add_mac_vendor(struct hash_control *, const char *);
+int add_mac_vendor(const char *);
 char *get_mac_vendor_filename(const char *, const char *, const char *);
 /* Wrappers */
 int Gettimeofday(struct timeval *);
@@ -260,8 +261,3 @@ double genrand_real1(void);
 double genrand_real2(void);
 double genrand_real3(void);
 double genrand_res53(void);
-/* The following functions are just to prevent rcsid being optimised away */
-void wrappers_use_rcsid(void);
-void error_use_rcsid(void);
-void utils_use_rcsid(void);
-void link_use_rcsid(void);
