@@ -1,24 +1,22 @@
 /*
- * The ARP scanner (arp-scan) is Copyright (C) 2005-2013
+ * The ARP scanner (arp-scan) is Copyright (C) 2005-2016
  * Roy Hills, NTA Monitor Ltd.
  *
  * This file is part of arp-scan.
- * 
+ *
  * arp-scan is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- * 
+ *
  * arp-scan is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with arp-scan.  If not, see <http://www.gnu.org/licenses/>.
  *
- * $Id: error.c 19550 2013-04-15 09:24:42Z rsh $
- *
  * error.c -- error routines for arp-scan
  *
  * Author:	Roy Hills
@@ -27,8 +25,6 @@
 
 #include "arp-scan.h"
 
-static char rcsid[] = "$Id: error.c 19550 2013-04-15 09:24:42Z rsh $"; /* RCS ID for ident(1) */
-
 int daemon_proc;	/* Non-zero if process is a daemon */
 
 /*
@@ -103,8 +99,3 @@ err_print (int errnoflag, const char *fmt, va_list ap) {
    fputs(buf, stderr);
    fflush(stderr);
 }
-
-void
-error_use_rcsid(void) {
-   fprintf(stderr, "%s\n", rcsid);	/* Use rcsid to stop compiler optimising away */
-}
