@@ -1,24 +1,22 @@
 /*
- * The ARP Scanner (arp-scan) is Copyright (C) 2005-2013 Roy Hills,
+ * The ARP Scanner (arp-scan) is Copyright (C) 2005-2016 Roy Hills,
  * NTA Monitor Ltd.
  *
  * This file is part of arp-scan.
- * 
+ *
  * arp-scan is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- * 
+ *
  * arp-scan is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with arp-scan.  If not, see <http://www.gnu.org/licenses/>.
  *
- * $Id: link-dlpi.c 19578 2013-04-25 15:44:27Z rsh $
- *
  * link-dlpi.c -- DLPI link layer send functions for arp-scan
  *
  * Author:	Roy Hills
@@ -70,8 +68,6 @@
  * unsigned char for our buffers and so must multiply by four */
 #define MAXDLBUF 8192*4
 
-static char const rcsid[] = "$Id: link-dlpi.c 19578 2013-04-25 15:44:27Z rsh $";   /* RCS ID for ident(1) */
-
 /*
  *	Link layer handle structure for DLPI.
  *	This is typedef'ed as link_t.
@@ -302,10 +298,3 @@ get_hardware_address(const char *if_name, unsigned char hw_address[]) {
    link_close(handle);
    memcpy(hw_address, buf + dlp->physaddr_ack.dl_addr_offset, ETH_ALEN);
 }
-
-/*
- *	Use rcsid to prevent the compiler optimising it away.
- */
-void link_use_rcsid(void) {
-   fprintf(stderr, "%s\n", rcsid);      /* Use rcsid to stop compiler optimising away */
-}
