@@ -1,24 +1,22 @@
 /*
- * The ARP Scanner (arp-scan) is Copyright (C) 2005-2013 Roy Hills,
+ * The ARP Scanner (arp-scan) is Copyright (C) 2005-2016 Roy Hills,
  * NTA Monitor Ltd.
  *
  * This file is part of arp-scan.
- * 
+ *
  * arp-scan is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- * 
+ *
  * arp-scan is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with arp-scan.  If not, see <http://www.gnu.org/licenses/>.
  *
- * $Id$
- *
  * link-packet-socket.c -- Packet socket link layer send functions for arp-scan
  *
  * Author:	Roy Hills
@@ -42,8 +40,6 @@
 #include <net/if.h>
 #endif
 
-static char const rcsid[] = "$Id$";   /* RCS ID for ident(1) */
-
 /*
  *	Link layer handle structure for packet socket.
  *	This is typedef'ed as link_t.
@@ -72,8 +68,8 @@ link_open(const char *device) {
    handle = Malloc(sizeof(*handle));
    memset(handle, '\0', sizeof(*handle));
    if ((handle->fd = socket(PF_PACKET, SOCK_RAW, 0)) < 0) {
-      free(handle);
-      return NULL;
+      warn_msg("ERROR: Cannot open raw packet socket");
+      err_sys("socket");
    }
    strlcpy(handle->ifr.ifr_name, device, sizeof(handle->ifr.ifr_name));
    if ((ioctl(handle->fd, SIOCGIFINDEX, &(handle->ifr))) != 0)
@@ -81,7 +77,7 @@ link_open(const char *device) {
    handle->sll.sll_family = PF_PACKET;
    handle->sll.sll_ifindex = handle->ifr.ifr_ifindex;
    handle->sll.sll_halen = ETH_ALEN;
-   
+
    return handle;
 }
 
@@ -131,10 +127,3 @@ get_hardware_address(const char *if_name, unsigned char hw_address[]) {
 
    memcpy(hw_address, handle->ifr.ifr_ifru.ifru_hwaddr.sa_data, ETH_ALEN);
 }
-
-/*
- *	Use rcsid to prevent the compiler optimising it away.
- */
-void link_use_rcsid(void) {
-   fprintf(stderr, "%s\n", rcsid);      /* Use rcsid to stop compiler optimising away */
-}
