@@ -1,26 +1,24 @@
 /*
- * The ARP Scanner (arp-scan) is Copyright (C) 2005-2013 Roy Hills,
+ * The ARP Scanner (arp-scan) is Copyright (C) 2005-2016 Roy Hills,
  * NTA Monitor Ltd.
  *
  * This file is part of arp-scan.
- * 
+ *
  * arp-scan is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- * 
+ *
  * arp-scan is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with arp-scan.  If not, see <http://www.gnu.org/licenses/>.
  *
- * You are encouraged to send comments, improvements or suggestions to
- * me at arp-scan@nta-monitor.com.
- *
- * $Id$
+ * You are encouraged to send comments, improvements or suggestions
+ * at the github repository https://github.com/royhills/arp-scan
  *
  * Author: Roy Hills
  * Date: 5 April 2004
@@ -30,9 +28,6 @@
 
 #include "arp-scan.h"
 
-static char rcsid[] = "$Id$";	/* RCS ID for ident(1) */
-
-
 /*
  *	timeval_diff -- Calculates the difference between two timevals
  *	and returns this difference in a third timeval.
@@ -66,7 +61,7 @@ timeval_diff(const struct timeval *a, const struct timeval *b,
      temp.tv_usec += 1000000 * nsec;
      temp.tv_sec -= nsec;
    }
- 
+
    /* Compute the time difference
       tv_usec is certainly positive. */
    diff->tv_sec = a->tv_sec - temp.tv_sec;
@@ -232,52 +227,6 @@ hexstring(const unsigned char *data, size_t size) {
    return result;
 }
 
-/*
- *	print_times -- Print absolute and delta time for debugging
- *
- *	Inputs:
- *
- *	None.
- *
- *	Returns:
- *
- *	None.
- *
- *	This function is only used for debugging.  It should not be called
- *	from production code.
- */
-void
-print_times(void) {
-   static struct timeval time_first;    /* When print_times() was first called */
-   static struct timeval time_last;     /* When print_times() was last called */
-   static int first_call=1;
-   struct timeval time_now;
-   struct timeval time_delta1;
-   struct timeval time_delta2;
-
-   Gettimeofday(&time_now);
-
-   if (first_call) {
-      first_call=0;
-      time_first.tv_sec  = time_now.tv_sec;
-      time_first.tv_usec = time_now.tv_usec;
-      printf("%lu.%.6lu (0.000000) [0.000000]\t",
-             (unsigned long)time_now.tv_sec, (unsigned long)time_now.tv_usec);
-   } else {
-      timeval_diff(&time_now, &time_last, &time_delta1);
-      timeval_diff(&time_now, &time_first, &time_delta2);
-      printf("%lu.%.6lu (%lu.%.6lu) [%lu.%.6lu]\t",
-             (unsigned long)time_now.tv_sec,
-             (unsigned long)time_now.tv_usec,
-             (unsigned long)time_delta1.tv_sec,
-             (unsigned long)time_delta1.tv_usec,
-             (unsigned long)time_delta2.tv_sec,
-             (unsigned long)time_delta2.tv_usec);
-   }
-   time_last.tv_sec  = time_now.tv_sec;
-   time_last.tv_usec = time_now.tv_usec;
-}
-
 /*
  * get_ether_addr -- Get Ethernet hardware address from text string
  *
@@ -437,7 +386,3 @@ dupstr(const char *str) {
    strlcpy(cp, str, len);
    return cp;
 }
-
-void utils_use_rcsid(void) {
-   fprintf(stderr, "%s\n", rcsid);	/* Use rcsid to stop compiler optimising away */
-}
