@@ -1,24 +1,22 @@
 /*
- * The ARP Scanner (arp-scan) is Copyright (C) 2005-2013 Roy Hills,
+ * The ARP Scanner (arp-scan) is Copyright (C) 2005-2016 Roy Hills,
  * NTA Monitor Ltd.
  *
  * This file is part of arp-scan.
- * 
+ *
  * arp-scan is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
- * 
+ *
  * arp-scan is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with arp-scan.  If not, see <http://www.gnu.org/licenses/>.
  *
- * $Id$
- *
  * Author: Roy Hills
  * Date: 8 November 2003
  *
@@ -36,8 +34,6 @@
 
 #include "arp-scan.h"
 
-static char rcsid[] = "$Id$";	/* RCS ID for ident(1) */
-
 /*
  * We omit the timezone arg from this wrapper since it's obsolete and we never
  * use it.
@@ -100,7 +96,3 @@ long int Strtol(const char *nptr, int base) {
 
    return result;
 }
-
-void wrappers_use_rcsid(void) {
-   fprintf(stderr, "%s\n", rcsid);	/* Use rcsid to stop compiler optimising away */
-}
